OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor, selecione um ficheiro.",
    "File is too big" : "O ficheiro é demasiado grande",
    "The selected file is not an image." : "O ficheiro selecionado não é uma imagem.",
    "The selected file cannot be read." : "O ficheiro selecionado não pode ser lido.",
    "The file was uploaded" : "O ficheiro foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro enviado excede a diretiva \"upload_max_filesize\" no php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O tamanho do ficheiro enviado excede a diretiva \"MAX_FILE_SIZE\" definida no formulário HTML",
    "The file was only partially uploaded" : "O ficheiro foi enviado apenas parcialmente",
    "No file was uploaded" : "Não foi enviado nenhum ficheiro",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Could not write file to disk" : "Não foi possível gravar o ficheiro no disco",
    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o envio do ficheiro.",
    "Invalid file provided" : "Fornecido ficheiro inválido",
    "No image or file provided" : "Imagem ou ficheiro não fornecido",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "An error occurred. Please contact your admin." : "Ocorreu um erro. Por favor, contacte o seu administrador.",
    "Invalid image" : "Imagem inválida",
    "No temporary profile picture available, try again" : "Nenhuma imagem de perfil temporária disponível, tente novamente",
    "No crop data provided" : "Não foram fornecidos dados de recorte",
    "No valid crop data provided" : "Não foram indicados dados de recorte válidos",
    "Crop is not square" : "O recorte não é quadrado",
    "State token does not match" : "O código de estado não corresponde",
    "Invalid app password" : "Palavra-passe da aplicação inválida",
    "Could not complete login" : "Não foi possível concluir a autenticação",
    "State token missing" : "O código de estado está em falta",
    "Your login token is invalid or has expired" : "O seu código de autenticação é inválido ou expirou",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "A versão comunitária da Nextcloud não tem suporte e as notificações a pedido são limitadas.",
    "Login" : "Iniciar sessão",
    "Password reset is disabled" : "A reposição da senha está desativada",
    "Could not reset password because the token is expired" : "Não foi possível redefinir a palavra-passe porque o token expirou",
    "Could not reset password because the token is invalid" : "Não foi possível redefinir a palavra-passe porque o token é inválido",
    "Password is too long. Maximum allowed length is 469 characters." : "A senha é muito longa. O comprimento máximo permitido é de 469 caracteres.",
    "%s password reset" : "%s reposição de palavra-passe",
    "Password reset" : "Reposição da senha",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clique no seguinte botão para repor a sua senha. Se não solicitou a reposição da senha, ignore este e-mail.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clique na seguinte hiperligação para repor a sua senha. Se não solicitou a reposição da senha, ignore este e-mail.",
    "Reset your password" : "Repor a senha",
    "Internal error" : "Erro interno",
    "Not found" : "Não foi encontrado",
    "Nextcloud Server" : "Nextcloud Server",
    "Some of your link shares have been removed" : "Algumas das suas partilhas de hiperligação foram removidas",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Devido a bugs de segurança tivemos que remover algumas das suas ligações às partilhas.\nPor favor veja o link para mais informação.",
    "Learn more ↗" : "Saiba mais ↗",
    "Preparing update" : "A preparar a atualização",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Etapa da reparação:",
    "Repair info:" : "Informação da reparação:",
    "Repair warning:" : "Aviso de reparação:",
    "Repair error:" : "Erro de reparação:",
    "Turned on maintenance mode" : "Ativou o modo de manutenção",
    "Turned off maintenance mode" : "Desativou o modo de manutenção",
    "Maintenance mode is kept active" : "O modo de manutenção é mantido ativo",
    "Updating database schema" : "A atualizar o esquema da base de dados",
    "Updated database" : "Base de dados atualizada",
    "Update app \"%s\" from App Store" : "Atualizar a aplicação \"%s\" a partir da Loja de Aplicações",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "A verificar se o esquema da base de dados para %s pode ser atualizado (isto pode demorar algum tempo, dependendo do tamanho da base de dados)",
    "Updated \"%1$s\" to %2$s" : "Atualizar \"%1$s\" para %2$s",
    "Set log level to debug" : "Definir nível de registo para depurar",
    "Reset log level" : "Reiniciar nível de registo",
    "Starting code integrity check" : "A iniciar a verificação da integridade do código",
    "Finished code integrity check" : "Terminada a verificação da integridade do código",
    "%s (incompatible)" : "%s (incompatível)",
    "The following apps have been disabled: %s" : "As seguintes aplicações foram desativadas: %s",
    "Already up to date" : "Já está atualizado",
    "Error occurred while checking server setup" : "Ocorreu um erro durante a verificação da configuração do servidor",
    "unknown text" : "texto desconhecido",
    "Hello world!" : "Olá, mundo!",
    "sunny" : "soalheiro",
    "Hello {name}, the weather is {weather}" : "Olá {name}, o tempo está {weather}",
    "Hello {name}" : "Olá {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Resultados da pesquisa<script>alert(1)</script></strong>",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros","transferir %n ficheiros"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "A actualização está a decorrer. Se deixar esta página o processo pode ser interrompido.",
    "Update to {version}" : "Atualizar para {version}",
    "An error occurred." : "Ocorreu um erro.",
    "Please reload the page." : "Por favor, recarregue a página.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização falhou. Para mais informação <a href=\"{url}\">consulte o nosso artigo do fórum</a> sobre como resolver este problema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi bem sucedida. Por favor, informe este problema à <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
    "Continue to {productName}" : "Continuar para {productName}",
    "Apps" : "Aplicações",
    "More apps" : "Mais apps",
    "No" : "Não",
    "Yes" : "Sim",
    "Failed to add the public link to your Nextcloud" : "Não foi possível adicionar a hiperligação pública ao seu Nextcloud",
    "Date" : "Data",
    "Today" : "Hoje",
    "Last year" : "Ultimo ano",
    "Results" : "Resultados",
    "Load more results" : "Mostrar mais resultados...",
    "Searching …" : "À procura …",
    "Start typing to search" : "Digitar para pesquisar",
    "Log in" : "Iniciar sessão",
    "Logging in …" : "A entrar...",
    "Server side authentication failed!" : "Autenticação do lado do servidor falhou!",
    "Please contact your administrator." : "Por favor, contacte o seu administrador.",
    "An internal error occurred." : "Ocorreu um erro interno.",
    "Please try again or contact your administrator." : "Por favor, tente novamente ou contacte o seu administrador.",
    "Password" : "Palavra-passe",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos múltiplas tentativas falhadas de login do seu IP. Por esse motivo, o seu próximo login será adiado por, até, 30 segundos. ",
    "Your account is not setup for passwordless login." : "A sua conta não está configurada para autenticação sem palavra-passe.",
    "Browser not supported" : "Navegador não suportado",
    "Passwordless authentication is not supported in your browser." : "O seu navegador não suporta autenticação sem palavra-passe.",
    "Your connection is not secure" : "A sua ligação não é segura",
    "Passwordless authentication is only available over a secure connection." : "A autenticação sem palavra-passe só está disponível através de uma ligação segura.",
    "Reset password" : "Repor palavra-passe",
    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar a mensagem de reposição. Por favor, contacte o seu administrador.",
    "Password cannot be changed. Please contact your administrator." : "A senha não pode ser alterada. Contacte o seu administrador.",
    "Back to login" : "Voltar à entrada",
    "New password" : "Nova palavra-passe",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Os seus ficheiros estão cifrados. Não será possível aceder aos seus dados após a palavra-passe ser alterada. Se não tiver a certeza do que fazer, contacte o administrador do sistema antes de continuar. Tem a certeza que quer continuar?",
    "I know what I'm doing" : "Eu sei o que eu estou a fazer",
    "Resetting password" : "A fazer reset à palavra passe",
    "Recommended apps" : "Aplicações recomendadas",
    "Loading apps …" : "A carregar aplicações...",
    "App download or installation failed" : "A transferência ou a instalação desta aplicação falhou",
    "Cannot install this app because it is not compatible" : "Não é possível instalar esta aplicação por não ser compatível",
    "Cannot install this app" : "Não é possível instalar esta aplicação",
    "Skip" : "Saltar",
    "Installing apps …" : "A instalar aplicações ...",
    "Install recommended apps" : "Instalar aplicações recomendadas",
    "Schedule work & meetings, synced with all your devices." : "Agende trabalho e reuniões, sincronizando com todos os seus dispositivos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha os seus colegas e amigos no mesmo lugar sem divulgar as suas informações privadas.",
    "Settings menu" : "Menu de configurações",
    "Reset search" : "Redefinir pesquisa",
    "Search contacts …" : "Pesquisar contactos...",
    "Could not load your contacts" : "Não foi possível carregar os seus contactos",
    "No contacts found" : "Não foram encontrados contactos",
    "Install the Contacts app" : "Instalar a app Contactos",
    "Loading your contacts …" : "A carregar os seus contactos",
    "Looking for {term} …" : "Procurando por {term} …",
    "Search for {name} only" : "Pesquisar apenas por {name}",
    "Loading more results …" : "A carregar mais resultados...",
    "Search" : "Procurar",
    "No results for {query}" : "Nenhum resultado para {query}",
    "An error occurred while searching for {type}" : "Ocorreu um erro enquanto pesquisava por {type}",
    "Forgot password?" : "Senha esquecida?",
    "Back" : "Anterior",
    "Edit Profile" : "Editar perfil",
    "You have not added any info yet" : "Ainda não adicionou qualquer informação ",
    "More actions" : "Mais acções",
    "This browser is not supported" : "O seu navegador não é suportado.",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "A versão do seu navegador não é suportada. Por favor atualize para uma versão mais recente ou para uma que seja suportada.",
    "Continue with this unsupported browser" : "Continuar com uma versão não suportada do navegador",
    "Supported versions" : "Versões suportadas",
    "{name} version {version} and above" : "{name} versão {version} e superior",
    "Search {types} …" : "Pesquisar {types}...",
    "Choose" : "Escolher",
    "Copy" : "Copiar",
    "Move" : "Mover",
    "OK" : "Confirmar",
    "read-only" : "só de leitura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de ficheiro","{count} conflitos de ficheiro","{count} conflitos de ficheiro"],
    "One file conflict" : "Um conflito de ficheiro",
    "New Files" : "Novos Ficheiros",
    "Already existing files" : "Ficheiros já existentes",
    "Which files do you want to keep?" : "Quais os ficheiros que pretende manter?",
    "If you select both versions, the copied file will have a number added to its name." : "Se selecionar ambas as versões, o ficheiro copiado irá ter um número adicionado ao seu nome.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos selecionados)",
    "({count} selected)" : "({count} selecionados)",
    "Error loading file exists template" : "Ocorreu um erro ao carregar o ficheiro do modelo existente",
    "Saving …" : "A guardar...",
    "seconds ago" : "segundos atrás",
    "Connection to server lost" : "Ligação perdida ao servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema a carregar a página. A recarregar dentro de %n segundos","Problema ao carregar a página. A recarregar dentro de %n segundos","Problema ao carregar a página. A recarregar dentro de %n segundos"],
    "Add to a project" : "Adicionar a um projeto",
    "Show details" : "Mostrar detalhes",
    "Hide details" : "Ocultar detalhes",
    "Rename project" : "Renomear projeto",
    "Failed to rename the project" : "Erro ao renomear o projeto",
    "Failed to create a project" : "Erro ao criar o projeto",
    "Failed to add the item to the project" : "Falha ao adicionar item ao projeto",
    "Connect items to a project to make them easier to find" : "Ligar itens a um projeto para poderem ser mais facilmente encontrados",
    "Type to search for existing projects" : "Digite para procurar por projetos existentes",
    "New in" : "Novo em",
    "View changelog" : "Ver Registo de alterações",
    "Very weak password" : "Palavra-passe muito fraca",
    "Weak password" : "Palavra-passe fraca",
    "So-so password" : "Palavra-passe aceitável",
    "Good password" : "Palavra-passe boa",
    "Strong password" : "Palavra-passe forte",
    "No action available" : "Nenhuma acção disponível",
    "Error fetching contact actions" : "Erro ao obter acções dos contactos",
    "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
    "Restricted" : "Restrito",
    "Invisible" : "Invisível ",
    "Delete" : "Eliminar",
    "Rename" : "Renomear",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "Etiquetas não encontradas",
    "Personal" : "Pessoal",
    "Admin" : "Administração",
    "Help" : "Ajuda",
    "Access forbidden" : "Acesso proibido",
    "Profile not found" : "Perfil não encontrado",
    "The profile does not exist." : "O perfil não existe.",
    "Back to %s" : "Voltar a %s",
    "Page not found" : "Página não encontrada",
    "Too many requests" : "Muitos pedidos",
    "Error" : "Erro",
    "Previous" : "Anterior",
    "Internal Server Error" : "Erro Interno do Servidor",
    "The server was unable to complete your request." : "O servidor não conseguiu completar o seu pedido.",
    "If this happens again, please send the technical details below to the server administrator." : "Se voltar a  acontecer, por favor envie os detalhes técnicos abaixo ao administrador do servidor.",
    "More details can be found in the server log." : "Mais detalhes podem ser encontrados no log do servidor.",
    "Technical details" : "Detalhes técnicos",
    "Remote Address: %s" : "Endereço remoto: %s",
    "Request ID: %s" : "ID do pedido: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensagem: %s",
    "File: %s" : "Ficheiro: %s",
    "Line: %s" : "Linha: %s",
    "Trace" : "Rastreio",
    "Security warning" : "Aviso de Segurança",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "A pasta de dados e os respetivos ficheiros estão provavelmente acessíveis a partir da internet pois o ficheiro .htaccess não funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter informações de como configurar correctamente o servidor, veja em: <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentação</a>.",
    "Create an <strong>admin account</strong>" : "Criar uma <strong>conta administrativa</strong>",
    "Show password" : "Mostrar senha",
    "Toggle password visibility" : "Altere a visibilidade da palavra-passe",
    "Storage & database" : "Armazenamento e base de dados",
    "Data folder" : "Pasta de dados",
    "Configure the database" : "Configure a base de dados",
    "Only %s is available." : "Só está disponível %s.",
    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos PHP adicionais para escolher outros tipos de base de dados.",
    "For more details check out the documentation." : "Para mais detalhes consulte a documentação.",
    "Database password" : "Palavra-passe da base de dados",
    "Database name" : "Nome da base de dados",
    "Database tablespace" : "Tablespace da base de dados",
    "Database host" : "Anfitrião da base de dados",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor, especifique o número da porta com o nome do anfitrião (por exemplo, localhost:5432).",
    "Performance warning" : "Aviso de desempenho",
    "You chose SQLite as database." : "Escolheu SQLite como base de dados",
    "Install" : "Instalar",
    "Installing …" : "A instalar...",
    "Need help?" : "Precisa de ajuda?",
    "See the documentation" : "Consulte a documentação",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicação requer JavaScript para funcionar corretamente. Por favor, {linkstart}ative o JavaScript{linkend} e recarregue a página.",
    "Skip to main content" : "Saltar para conteúdo principal",
    "Skip to navigation of app" : "Saltar para navegação da aplicação",
    "Go to %s" : "Ir para %s",
    "Get your own free account" : "Obtenha a sua própria conta grátis",
    "Connect to your account" : "Ligar à sua conta",
    "Please log in before granting %1$s access to your %2$s account." : "Por favor, autentique-se antes de permitir o acesso de %1$s à sua conta %2$s.",
    "Grant access" : "Conceder acesso",
    "Account access" : "Acesso à conta",
    "You are about to grant %1$s access to your %2$s account." : "Está prestes a permitir a %1$s aceder à sua conta conta %2$s. ",
    "Account connected" : "Conta ligada",
    "You can close this window." : "Pode fechar esta janela.",
    "This share is password-protected" : "Esta partilha está protegida por senha",
    "Email address" : "Endereço de email",
    "Two-factor authentication" : "Autenticação de dois fatores",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "A segurança reforçada foi ativada para a sua conta. Por favor, escolha um segundo fator de autenticação.",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Não foi possível carregar pelo menos um dos métodos de autenticação de dois passos activados. Por favor, contacte o seu administrador.",
    "Set up two-factor authentication" : "Configurar autenticação de dois fatores",
    "Use backup code" : "Usar código de cópia de segurança",
    "Cancel login" : "Cancelar login",
    "Error while validating your second factor" : "Erro ao validar o segundo fator",
    "Access through untrusted domain" : "Aceder através de um domínio não confiável",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacte o seu administrador. Se é um administrador, edite a definição \"trusted_domains\" no config/config.php como no exemplo em config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Mais informação acerca de como configurar pode ser encontrada na %1$sdocumentação%2$s. ",
    "App update required" : "É necessário atualizar a aplicação",
    "%1$s will be updated to version %2$s" : "%1$s irá ser atualizada para a versão %2$s",
    "These incompatible apps will be disabled:" : "Estas aplicações incompatíveis irão ser desativadas:",
    "The theme %s has been disabled." : "O tema %s foi desativado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que foi efetuada uma cópia de segurança da base de dados, pasta de configuração e de dados antes de prosseguir.",
    "Start update" : "Iniciar atualização",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos limites com instalações maiores, pode executar o seguinte comando na diretoria de instalação:",
    "Detailed logs" : "Registos detalhados",
    "Update needed" : "É necessário atualizar",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para obter ajuda, consulte a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentação</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continuar a fazer a atualização via interface web arrisco a que o pedido expire e pode causar a perda de dados, no entanto tenho uma cópia de segurança e sei como restaurar a minha instância em caso de falha. ",
    "Upgrade via web on my own risk" : "Atualizar via web por minha conta e risco.",
    "Maintenance mode" : "Modo de manutenção",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está atualmente no modo de manutenção, o que poderá demorar algum tempo.",
    "This page will refresh itself when the instance is available again." : "Esta página irá ser atualizada quando a instância ficar novamente disponível.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador do sistema se esta mensagem persistir ou apareceu inesperadamente.",
    "The user limit of this instance is reached." : "O limite de utilizador desta instância foi atingido",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "O seu servidor da Web não está configurado corretamente para permitir a sincronização de ficheiros, porque a interface WebDAV parece estar com problemas.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "O seu webserver não está configurado correctamente resolver \"{url}\". Pode encontrar mais informações na documentação {linkstart} ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "O seu servidor web não está configurado correctamente para resolver \"{url}\". Provavelmente, isso está relacionado a uma configuração do servidor web que não foi actualizada para entregar essa pasta directamente. Compare a sua configuração com as regras de reescrita disponibilizadas em \".htaccess\" para Apache ou as fornecida na documentação para Nginx na {linkstart}página de documentação ↗{linkend}. No Nginx essas são normalmente as linhas que começam com \"location ~\" que precisam de uma actualização. ",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "O seu servidor web não está configurado correctamente para entregar arquivos .woff2. Normalmente, esse é um problema com a configuração do Nginx. Para o Nextcloud 15, é necessário um ajuste para entregar também arquivos .woff2. Compare sua configuração Nginx com a configuração recomendada na nossa {linkstart}documentação ↗{linkend}.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido como \"{expected}\". Isto é um potencial risco de segurança ou privacidade, pelo que recomendamos que ajuste esta opção em conformidade.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido como \"{expected}\". Algumas funcionalidades poderão não funcionar correctamente, pelo que recomendamos que ajuste esta opção em conformidade.",
    "Wrong username or password." : "Nome de utilizador ou palavra passe errados",
    "User disabled" : "Utilizador desativado",
    "Username or email" : "Utilizador ou e-mail",
    "Error loading message template: {error}" : "Ocorreu um erro ao carregar o modelo: {error}",
    "Users" : "Utilizadores",
    "Username" : "Nome de utilizador",
    "Database user" : "Utilizador da base de dados",
    "This action requires you to confirm your password" : "Esta ação requer a confirmação da senha",
    "Confirm your password" : "Confirmar senha",
    "Confirm" : "Confirmar",
    "App token" : "Token da aplicação",
    "Alternative log in using app token" : "Autenticação alternativa usando token da aplicação",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Por favor, use o atualizador da linha de comandos porque tem uma instância grande com mais de 50 utilizadores."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
